@@ -1,4 +1,4 @@
-# Copyright 2016, 2017 IBM Corp.
+# Copyright 2016, 2020 IBM Corp.
 #
 # All Rights Reserved.
 #
@@ -25,6 +25,7 @@ import pickle
 import six
 import warnings
 
+from oslo_serialization import base64 as base64utils
 from pypowervm import exceptions as pvm_ex
 from pypowervm.i18n import _
 from pypowervm import util as pvm_util
@@ -74,7 +75,14 @@ class SlotMapStore(object):
         self._vswitch_map = None
         map_str = self.load() if load else None
         # Deserialize or initialize
-        self._slot_topo = pickle.loads(map_str) if map_str else {}
+        try:
+            self._slot_topo = pickle.loads(
+                base64utils.decode_as_bytes(map_str)) if map_str else {}
+        except UnicodeDecodeError:
+            # Retain old way of decoding slot map data. This is required
+            # for virtual machines deployed on a py2 env and upgraded to
+            # py3.
+            self._slot_topo = pickle.loads(map_str) if map_str else {}
         # Save a copy of the topology so we can tell when it has changed
         self._loaded_topo = copy.deepcopy(self._slot_topo)
 
@@ -212,7 +220,14 @@ class SlotMapStore(object):
                        be incorporated.
         :param fab: The fabric name associated with the mapping.
         """
-        self._reg_slot(IOCLASS.VFC, fab, vfcmap.server_adapter.lpar_slot_num)
+        if vfcmap.client_adapter:
+            wwpn_list = vfcmap.client_adapter.wwpns
+            self._reg_slot(IOCLASS.VFC, fab,
+                           vfcmap.server_adapter.lpar_slot_num,
+                           extra_spec=wwpn_list)
+        else:
+            self._reg_slot(IOCLASS.VFC, fab,
+                           vfcmap.server_adapter.lpar_slot_num)
 
     def drop_vfc_mapping(self, vfcmap, fab):
         """Drops the client network adapter from the slot topology.
@@ -726,14 +741,18 @@ class RebuildSlotMap(BuildSlotMap):
         seen_fabrics = set()
         for fabric in fabrics:
             fabric_slots = []
+            fabric_wwpn = {}
             # Add the slot numbers for this fabric
             for slot, iomap in six.iteritems(self._slot_store.topology):
                 if fabric not in iomap.get(IOCLASS.VFC, {}):
                     continue
                 fabric_slots.append(slot)
+                fabric_wwpn[slot] = iomap.get(IOCLASS.VFC, {}).get(fabric, {})
                 seen_fabrics.add(fabric)
 
+            fabric_slot = fabric + '_wwpn'
             self._put_novios_val(IOCLASS.VFC, fabric, fabric_slots)
+            self._put_novios_val(IOCLASS.VFC, fabric_slot, fabric_wwpn)
 
         # Make sure all the topology's fabrics are accounted for.
         # topo_fabrics is all the fabrics in all the slots from the slot_map
