@@ -65,6 +65,45 @@ class TestVterm(testtools.TestCase):
                                                '--local'])
         self.assertEqual(5903, resp)
 
+    @mock.patch('pypowervm.tasks.vterm._get_lpar_type')
+    @mock.patch('pypowervm.tasks.vterm._get_lpar_id')
+    @mock.patch('pypowervm.tasks.vterm._run_proc')
+    def test_open_vnc_vterm_ibmi(self, mock_run_proc,
+                                 mock_get_lpar_id, mock_get_lpar_type):
+        """Validates the mkvterm command for ibmi console."""
+        mock_get_lpar_id.return_value = '4'
+        mock_get_lpar_type.return_value = 'OS400'
+        std_out = '5903'
+        std_err = ('VNC is started on port 5903 for localhost access '
+                   'only.  Use \'rmvterm --id 4\' to close it.')
+        mock_run_proc.return_value = (0, std_out, std_err)
+
+        resp = vterm.open_localhost_vnc_vterm(self.adpt, 'lpar_uuid')
+
+        mock_run_proc.assert_called_once_with(['mkvterm', '--id', '4', '--vnc',
+                                               '--local', '--consolesettings',
+                                               'codepage=037'])
+        self.assertEqual(5903, resp)
+
+    @mock.patch('pypowervm.tasks.vterm._get_lpar_type')
+    @mock.patch('pypowervm.tasks.vterm._get_lpar_id')
+    @mock.patch('pypowervm.tasks.vterm._run_proc')
+    def test_open_vnc_vterm_non_ibmi(self, mock_run_proc,
+                                     mock_get_lpar_id, mock_get_lpar_type):
+        """Validates the mkvterm command for non ibmi console."""
+        mock_get_lpar_id.return_value = '4'
+        mock_get_lpar_type.return_value = 'AIX/Linux'
+        std_out = '5903'
+        std_err = ('VNC is started on port 5903 for localhost access '
+                   'only.  Use \'rmvterm --id 4\' to close it.')
+        mock_run_proc.return_value = (0, std_out, std_err)
+
+        resp = vterm.open_localhost_vnc_vterm(self.adpt, 'lpar_uuid')
+
+        mock_run_proc.assert_called_once_with(['mkvterm', '--id', '4', '--vnc',
+                                               '--local'])
+        self.assertEqual(5903, resp)
+
     @mock.patch('pypowervm.tasks.vterm._get_lpar_id')
     @mock.patch('pypowervm.tasks.vterm._run_proc')
     def test_open_vnc_vterm_existing(self, mock_run_proc, mock_get_lpar_id):
@@ -85,7 +124,7 @@ class TestVterm(testtools.TestCase):
     @mock.patch('pypowervm.tasks.vterm._get_lpar_id')
     def test_open_vnc_vterm_nonascii(self, mock_get_lpar_id, mock_popen):
         """Validates errors in non-ascii encodings are handled properly"""
-        proc_mock = mock.Mock(returncode=3)
+        proc_mock = mock.Mock(returncode=4)
         mock_get_lpar_id.return_value = '4'
         mock_popen.return_value = proc_mock
         proc_mock.communicate.return_value = ('', '\xd0\x92')
@@ -129,7 +168,7 @@ class TestVterm(testtools.TestCase):
         std_out = ""
         std_err = ("The vterm is currently in use by process 120352.  "
                    "Use 'rmvterm --id 4' to close it.")
-        mock_run_proc.return_value = (3, std_out, std_err)
+        mock_run_proc.return_value = (4, std_out, std_err)
 
         self.assertRaises(pexc.VNCBasedTerminalFailedToOpen,
                           vterm.open_localhost_vnc_vterm, self.adpt,
@@ -231,12 +270,12 @@ class TestVNCSocketListener(testtools.TestCase):
         mock_sock.return_value = mock_s_sock
         mock_select.return_value = [mock_c_sock], None, None
         mock_srv.accept.return_value = mock_c_sock, ('1.2.3.5', '40675')
-        mock_c_sock.recv.return_value = "CONNECT path HTTP/1.8\r\n\r\n"
+        mock_c_sock.recv.return_value = b"CONNECT path HTTP/1.8\r\n\r\n"
 
         self.srv._new_client(mock_srv)
 
         mock_c_sock.sendall.assert_called_once_with(
-            "HTTP/1.8 200 OK\r\n\r\n")
+            b"HTTP/1.8 200 OK\r\n\r\n")
         mock_s_sock.connect.assert_called_once_with(('127.0.0.1', '5800'))
 
         self.assertEqual({mock_c_sock: mock_s_sock, mock_s_sock: mock_c_sock},
@@ -250,12 +289,11 @@ class TestVNCSocketListener(testtools.TestCase):
         mock_sock.return_value = mock_s_sock
         mock_select.return_value = [mock_c_sock], None, None
         mock_srv.accept.return_value = mock_c_sock, ('fe80:7890', '40675')
-        mock_c_sock.recv.return_value = "CONNECT path HTTP/1.8\r\n\r\n"
-
+        mock_c_sock.recv.return_value = b"CONNECT path HTTP/1.8\r\n\r\n"
         self.srv_6._new_client(mock_srv)
 
         mock_c_sock.sendall.assert_called_once_with(
-            "HTTP/1.8 200 OK\r\n\r\n")
+            b"HTTP/1.8 200 OK\r\n\r\n")
         mock_s_sock.connect.assert_called_once_with(('127.0.0.1', '5800'))
 
         self.assertEqual({mock_c_sock: mock_s_sock, mock_s_sock: mock_c_sock},
@@ -263,14 +301,14 @@ class TestVNCSocketListener(testtools.TestCase):
 
     def test_check_http_connect(self):
         sock = mock.MagicMock()
-        sock.recv.return_value = "INVALID"
+        sock.recv.return_value = b"INVALID"
         uuid, http_code = self.srv._check_http_connect(sock)
         self.assertIsNone(uuid)
         self.assertEqual('1.1', http_code)
 
         # Test a good string
         sock.reset_mock()
-        sock.recv.return_value = 'CONNECT test HTTP/2.0\r\n\r\n'
+        sock.recv.return_value = b'CONNECT test HTTP/2.0\r\n\r\n'
         uuid, http_code = self.srv._check_http_connect(sock)
         self.assertEqual('uuid', uuid)
         self.assertEqual('2.0', http_code)
@@ -313,11 +351,11 @@ class TestVNCSocketListener(testtools.TestCase):
         # Reset the select so that the validation check fails
         mock_c_sock.reset_mock()
         mock_select.return_value = [mock_c_sock], None, None
-        mock_c_sock.recv.return_value = 'bad_check'
+        mock_c_sock.recv.return_value = b'bad_check'
         self.srv._new_client(mock_srv)
         self.assertEqual(self.rptr.peers, {})
         mock_c_sock.sendall.assert_called_with(
-            "HTTP/1.1 400 Bad Request\r\n\r\n")
+            b"HTTP/1.1 400 Bad Request\r\n\r\n")
         self.assertEqual(1, mock_c_sock.close.call_count)
 
     @mock.patch('pypowervm.tasks.vterm._close_vterm_local')
@@ -454,7 +492,7 @@ class _FakeSocket(object):
 
     def recv(self, bufsize):
         bufsize = bufsize if isinstance(bufsize, int) else ord(bufsize)
-        chunk = self.recv_buffer[self.recv_bytes:self.recv_bytes+bufsize]
+        chunk = self.recv_buffer[self.recv_bytes:self.recv_bytes + bufsize]
         if not isinstance(chunk, six.binary_type):
             chunk = six.binary_type(chunk, 'utf-8')
         self.recv_bytes += bufsize
